/*  Copyright (C) 2004 by jsoto
    2007-09-11 E-AC3 support added by www.madshi.net
    2009 Chumbo mod to autofill delay values from filename
    Copyright (C) 2010 by Adam Thomas-Murphy

    This file is part of DelayCut.

    DelayCut is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    DelayCut is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with DelayCut.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "delaycut.h"
#include "ui_delaycut.h"

#include <QIntValidator>
#include <QFileDialog>
#include <QStringListModel>
#include <QMessageBox>

#include "delayac3.h"
#include "types.h"

#include <cstdio>

DelayCut::DelayCut(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::DelayCut),
    crcMode("IGNORED"),
    abort(false),
    isCLI(false),
    writeConsole(false)
{
    ui->setupUi(this);
    delayac3 = new Delayac3;
    delayac3->ac3_crc_init();
    stringModel = new QStringListModel;
    fileInfo = new FILEINFO;
    validator = new QIntValidator(0, 99999999, this);
    ui->startCuttingLineEdit->setValidator(validator);
    ui->endCuttingLineEdit->setValidator(validator);
    ui->startDelayLineEdit->setValidator(validator);
    ui->endDelayLineEdit->setValidator(validator);
    connect(ui->inputFileLineEdit, SIGNAL(onDropEvent(QString)), this, SLOT(onFileDropped(QString)));
    connect(ui->outputFileLineEdit, SIGNAL(onDropEvent(QString)), this, SLOT(onFileDropped(QString)));
    connect(delayac3, SIGNAL(UpdateProgress(qint32)), this, SLOT(onUpdateProgress(qint32)));
}

DelayCut::~DelayCut()
{
    delete ui;
}

void DelayCut::keyPressEvent(QKeyEvent* event)
{
    if (ui->processButton->isEnabled() && event->key() == Qt::Key_Return)
    {
        on_processButton_clicked();
    }
    if (event->key() == Qt::Key_Escape)
    {
        on_quitButton_clicked();
    }
}

bool DelayCut::execute()
{
    outputFile = fopen(ui->outputFileLineEdit->text().toUtf8().constData(),"wb");
    if (!outputFile)
    {
        return false;
    }

    inputFile = fopen(ui->inputFileLineEdit->text().toUtf8().constData(),"rb");
    if (!inputFile)
    {
        fclose(outputFile);
        return false;
    }

    logFile = fopen(logFileName.toUtf8().constData(), "a");
    if (!logFile)
    {
        fclose(outputFile);
        fclose(inputFile);
        return false;
    }

    bool ret;
    QString extension = QFileInfo(ui->inputFileLineEdit->text()).suffix();

    if (extension == "wav")
    {
        ret = delayac3->delaywav(inputFile, outputFile, logFile, fileInfo, isCLI, abort, crcMode, writeConsole);
    }
    if (extension == "ac3")
    {
        ret = delayac3->delayac3(inputFile, outputFile, logFile, fileInfo, isCLI, abort, crcMode, writeConsole);
    }
    if (extension == "eac3" || extension == "ddp" || extension == "ec3" || extension == "dd+")
    {
        ret = delayac3->delayeac3(inputFile, outputFile, logFile, fileInfo, isCLI, abort, crcMode, writeConsole);
    }
    if (extension == "dts")
    {
        ret = delayac3->delaydts(inputFile, outputFile, logFile, fileInfo, isCLI, abort, crcMode, writeConsole);
    }
    if (extension == "mpa" || extension == "mp2" || extension == "mp3" )
    {
        ret = delayac3->delaympa(inputFile, outputFile, logFile, fileInfo, isCLI, abort, crcMode, writeConsole);
    }

    fclose(outputFile);
    fclose(inputFile);
    fclose(logFile);

    return ret;
}

void DelayCut::on_inputBrowseButton_clicked()
{
    QString fileName = QFileDialog::getOpenFileName(this, tr("Select input file"),
                                                    lastOpenDir == "" ? QDir::homePath() : lastOpenDir,
                                                    tr("All supported files (*.wav *.mpa *.ac3 *.eac3 *.ddp *.ec3 *.dd+ *.dts);;wave files (*.wav);;"
                                                       "mpeg1 files (*.mpa);;dolby files (*.ac3);;eac3 files (*.eac3 *.ddp *.ec3 *.dd+);;dts files (*.dts);;All Files (*.*)")
                                                    );

    if (fileName.isNull() || fileName.isEmpty()) return;

    ui->inputFileLineEdit->setText(QDir::toNativeSeparators(fileName));
    lastOpenDir = QFileInfo(fileName).absolutePath();
    SetOutputPath(fileName);
    GetInputFileInfo(fileName.toUtf8().constData());
    CalculateTarget(fileName);
}

void DelayCut::on_outputBrowseButton_clicked()
{
    QString fileName = QFileDialog::getSaveFileName(this, tr("Select output file"),
                                                    lastSaveDir == "" ? lastOpenDir : lastSaveDir,
                                                    tr("ac3 files (*.ac3);;eac3 files (*.eac3 *.ddp *.ec3 *.dd+);;dts files (*.dts)")
                                                    );
    if (fileName.isNull() || fileName.isEmpty()) return;

    lastSaveDir = QFileInfo(fileName).absolutePath();
}

void DelayCut::onFileDropped(QString fileName)
{
    qint32 startIndex = fileName.toLower().indexOf("delay") + 6;

    if (startIndex > 0)
    {
        qint32 endIndex = fileName.toLower().indexOf("ms", startIndex);
        ui->startDelayLineEdit->setText(fileName.mid(startIndex, endIndex - startIndex));
    }

    ui->inputFileLineEdit->setText(QDir::toNativeSeparators(fileName));
    lastOpenDir = QFileInfo(fileName).absolutePath();
    SetOutputPath(fileName);
    GetInputFileInfo(fileName.toUtf8().constData());
    CalculateTarget(fileName);
}

void DelayCut::on_inputFileLineEdit_textEdited(const QString &fileName)
{
    if (!QFile(fileName).exists())
    {
        Reset();
        return;
    }

    lastOpenDir = QFileInfo(fileName).absolutePath();
    SetOutputPath(fileName);
    GetInputFileInfo(fileName.toUtf8().constData());
    CalculateTarget(fileName);
}

void DelayCut::Reset()
{
    ui->outputBrowseButton->setEnabled(false);
    ui->infoTextEdit->clear();
    ui->ignoreRadioButton->setChecked(true);
    ui->ignoreRadioButton->setEnabled(false);
    ui->fixRadioButton->setEnabled(false);
    ui->silenceRadioButton->setEnabled(false);
    ui->skipRadioButton->setEnabled(false);
    ui->processButton->setEnabled(false);
}

void DelayCut::SetOutputPath(QString fileName)
{
    QString extension = QFileInfo(fileName).suffix();
    QString outputFileName = fileName.mid(0, fileName.lastIndexOf(".")) + "_fixed." + extension;
    ui->outputFileLineEdit->setText(QDir::toNativeSeparators(outputFileName));
    ui->outputFileLineEdit->setCursorPosition(0);
}

void DelayCut::GetInputFileInfo(const char *fileName)
{
    inputFile = fopen(fileName, "rb");
    QString extension = QFileInfo(fileName).suffix().toLower();

    if (extension == "wav")
    {
        delayac3->getwavinfo(inputFile, fileInfo);
    }
    if (extension == "ac3")
    {
        delayac3->getac3info(inputFile, fileInfo);
    }
    if (extension == "eac3" || extension == "ddp" || extension == "ec3" || extension == "dd+")
    {
        delayac3->geteac3info(inputFile, fileInfo);
    }
    if (extension == "dts")
    {
        delayac3->getdtsinfo(inputFile, fileInfo);
    }
    if (extension == "mpa" || extension == "mp2" || extension == "mp3")
    {
        delayac3->getmpainfo(inputFile, fileInfo);
    }
    fclose(inputFile);

    ui->infoTextEdit->clear();
    ui->infoTextEdit->insertPlainText("====== INPUT FILE INFO ========================\n");
    ui->infoTextEdit->insertPlainText(QString("File is          \t%1\n").arg(fileInfo->csType));
    if (fileInfo->csType != "unknown" && fileInfo->csType != "wav")
    {
        ui->infoTextEdit->insertPlainText(QString("Bitrate  (kbit/s)\t%1\n").arg(fileInfo->iBitrate));
        ui->infoTextEdit->insertPlainText(QString("Act rate (kbit/s) \t%1\n").arg(fileInfo->dactrate, 5, 'f', 3));
        ui->infoTextEdit->insertPlainText(QString("File size (bytes)\t%1\n").arg(fileInfo->i64Filesize));
        ui->infoTextEdit->insertPlainText(QString("Channels mode \t%1\n").arg(fileInfo->csMode));
        ui->infoTextEdit->insertPlainText(QString("Sampling Frec    \t%1\n").arg(fileInfo->fsample));
        ui->infoTextEdit->insertPlainText(QString("Low Frec Effects \t%1\n").arg(fileInfo->csLFE));
        ui->infoTextEdit->insertPlainText(QString("Duration         \t%1\n").arg(fileInfo->csOriginalDuration));
        ui->infoTextEdit->insertPlainText(QString("Frame length (ms)\t%1\n").arg(fileInfo->dFrameduration, 8, 'f', 6));
        ui->infoTextEdit->insertPlainText(QString("Frames/second    \t%1\n").arg(fileInfo->dFramesPerSecond, 8, 'L', 6));
        ui->infoTextEdit->insertPlainText(QString("Num of frames    \t%1\n").arg(fileInfo->i64TotalFrames));
        ui->infoTextEdit->insertPlainText(QString("Bytes per Frame  \t%1\n").arg(fileInfo->dBytesperframe, 9, 'L', 4));
        ui->infoTextEdit->insertPlainText(QString("Size % Framesize \t%1\n").arg(fileInfo->i64rest));
        if (fileInfo->cpf)
        {
            ui->infoTextEdit->insertPlainText(QString("CRC present: \tYES\n"));
        }
        else
        {
            ui->infoTextEdit->insertPlainText(QString("CRC present: \tNO\n"));
        }
    }
    if (fileInfo->csType == "wav")
    {
        ui->infoTextEdit->insertPlainText(QString("Bitrate  (kbit/s) \t%1\n").arg(fileInfo->iBitrate));
        ui->infoTextEdit->insertPlainText(QString("Act rate (kbit/s) \t%1\n").arg(fileInfo->dactrate, 5, 'f', 3));
        ui->infoTextEdit->insertPlainText(QString("Byte rate (kbit/s) \t%1\n").arg(fileInfo->iByterate));
        ui->infoTextEdit->insertPlainText(QString("File size (bytes)\t%1\n").arg(fileInfo->i64Filesize));
        ui->infoTextEdit->insertPlainText(QString("Channels mode    \t%1\n").arg(fileInfo->csMode));
        ui->infoTextEdit->insertPlainText(QString("Sampling Frec    \t%1\n").arg(fileInfo->fsample));
        ui->infoTextEdit->insertPlainText(QString("Bits of Prec.    \t%1\n").arg(fileInfo->iBits));
        ui->infoTextEdit->insertPlainText(QString("Duration         \t%1\n").arg(fileInfo->csOriginalDuration));
        ui->infoTextEdit->insertPlainText(QString("Sample length (ms)\t%1\n").arg(fileInfo->dFrameduration, 8, 'f', 6));
        ui->infoTextEdit->insertPlainText(QString("Num of samples   \t%1\n").arg(fileInfo->i64TotalFrames));
        ui->infoTextEdit->insertPlainText(QString("Bytes per Sample  \t%1\n").arg(fileInfo->dBytesperframe, 1, 'f', 0));
        ui->infoTextEdit->insertPlainText(QString("Size % Samplesize \t%1\n").arg(fileInfo->i64rest));
    }
    ui->infoTextEdit->insertPlainText(QString("=============================================\n"));
}

void DelayCut::CalculateTarget(QString fileName)
{
    qreal startCut, endCut, startDelay, endDelay;

    QString extension = QFileInfo(fileName).suffix().toLower();
    if ((extension == "ac3" || extension == "mpa" || extension == "mp2") &&
        (fileInfo->layer == 2 && fileInfo->cpf != 0))
    {
        ui->ignoreRadioButton->setEnabled(true);
        ui->fixRadioButton->setEnabled(true);
        ui->silenceRadioButton->setEnabled(true);
        ui->silenceRadioButton->setChecked(true);
        ui->skipRadioButton->setEnabled(true);
    }
    else
    {
        ui->ignoreRadioButton->setChecked(true);
        ui->ignoreRadioButton->setEnabled(false);
        ui->fixRadioButton->setEnabled(false);
        ui->silenceRadioButton->setEnabled(false);
        ui->skipRadioButton->setEnabled(false);
    }
    ui->outputBrowseButton->setEnabled(true);
    ui->processButton->setEnabled(true);

    if (ui->cutFileCheckBox->isChecked())
    {
        startCut = ui->startCuttingLineEdit->text().toInt() / 1000.0;
        endCut = ui->endCuttingLineEdit->text().toInt() / 1000.0;
    }
    else
    {
        endCut = startCut = 0.0;
    }

    startDelay = ui->startDelayLineEdit->text().toInt();
    endDelay = ui->endDelayLineEdit->text().toInt();

    delayac3->gettargetinfo(fileInfo, startDelay, endDelay, startCut, endCut);

    ui->infoTextEdit->insertPlainText("====== TARGET FILE INFO ======================\n");
    if (fileInfo->csType!="unknown" && fileInfo->csType!="wav")
    {
        ui->infoTextEdit->insertPlainText(QString("Start Frame   \t%1\n").arg(fileInfo->i64StartFrame));
        ui->infoTextEdit->insertPlainText(QString("End Frame     \t%1\n").arg(fileInfo->i64EndFrame));
        ui->infoTextEdit->insertPlainText(QString("Num of Frames \t%1\n").arg((fileInfo->i64EndFrame - fileInfo->i64StartFrame) + 1));
        ui->infoTextEdit->insertPlainText(QString("Duration      \t%1\n").arg(fileInfo->csTimeLengthEst));
        ui->infoTextEdit->insertPlainText(QString("NotFixedDelay \t%1\n").arg(fileInfo->dNotFixedDelay, 5, 'f', 4));
    }
    if (fileInfo->csType=="wav")
    {
        ui->infoTextEdit->insertPlainText(QString("Start Sample   \t%1\n").arg(fileInfo->i64StartFrame));
        ui->infoTextEdit->insertPlainText(QString("End Sample     \t%1\n").arg(fileInfo->i64EndFrame));
        ui->infoTextEdit->insertPlainText(QString("Num of Samples \t%1\n").arg((fileInfo->i64EndFrame - fileInfo->i64StartFrame) + 1));
        ui->infoTextEdit->insertPlainText(QString("Duration       \t%1\n").arg(fileInfo->csTimeLengthEst));
        ui->infoTextEdit->insertPlainText(QString("NotFixedDelay  \t%1\n").arg(fileInfo->dNotFixedDelay, 5, 'f', 4));
    }
    ui->infoTextEdit->insertPlainText("=============================================\n");
}

void DelayCut::on_ignoreRadioButton_toggled(bool checked)
{
    if (checked)
    {
        ui->fixRadioButton->setChecked(false);
        ui->silenceRadioButton->setChecked(false);
        ui->skipRadioButton->setChecked(false);
        crcMode = "IGNORED";
    }
}

void DelayCut::on_fixRadioButton_toggled(bool checked)
{
    if (checked)
    {
        ui->ignoreRadioButton->setChecked(false);
        ui->silenceRadioButton->setChecked(false);
        ui->skipRadioButton->setChecked(false);
        crcMode = "FIXED";
    }
}

void DelayCut::on_silenceRadioButton_toggled(bool checked)
{
    if (checked)
    {
        ui->ignoreRadioButton->setChecked(false);
        ui->fixRadioButton->setChecked(false);
        ui->skipRadioButton->setChecked(false);
        crcMode = "SILENCED";
    }
}

void DelayCut::on_skipRadioButton_toggled(bool checked)
{
    if (checked)
    {
        ui->ignoreRadioButton->setChecked(false);
        ui->fixRadioButton->setChecked(false);
        ui->silenceRadioButton->setChecked(false);
        crcMode = "SKIPPED";
    }
}

void DelayCut::on_originalLengthCheckBox_toggled(bool checked)
{
    if (checked)
    {
        ui->endDelayLineEdit->setText(ui->startDelayLineEdit->text());
        if (!ui->inputFileLineEdit->text().isEmpty())
        {
            QString fileName = ui->inputFileLineEdit->text();
            GetInputFileInfo(ui->inputFileLineEdit->text().toUtf8().constData());
            CalculateTarget(fileName);
        }
    }
    ui->endDelayLineEdit->setEnabled(!checked);
    ui->endDelayLineEdit->setEnabled(!checked);
}

void DelayCut::on_startCuttingLineEdit_textEdited(const QString &startCut)
{
    if (ui->startCuttingLineEdit->text().isEmpty())
    {
        ui->startCuttingLineEdit->setText("0");
    }
    if (ui->endCuttingLineEdit->text().toInt() < ui->startCuttingLineEdit->text().toInt())
    {
        ui->endCuttingLineEdit->setText(startCut);
    }
    if (!ui->inputFileLineEdit->text().isEmpty())
    {
        QString fileName = ui->inputFileLineEdit->text();
        GetInputFileInfo(fileName.toUtf8().constData());
        CalculateTarget(fileName);
    }
}

void DelayCut::on_endCuttingLineEdit_textEdited(const QString &endCut)
{
    if (ui->endCuttingLineEdit->text().isEmpty())
    {
        ui->endCuttingLineEdit->setText("0");
    }
    if (ui->endCuttingLineEdit->text().toInt() < ui->startCuttingLineEdit->text().toInt())
    {
        ui->endCuttingLineEdit->setText(QString::number(ui->startCuttingLineEdit->text().toInt()));
    }
    if (!ui->inputFileLineEdit->text().isEmpty())
    {
        QString fileName = ui->inputFileLineEdit->text();
        GetInputFileInfo(ui->inputFileLineEdit->text().toUtf8().constData());
        CalculateTarget(fileName);
    }
}

void DelayCut::on_startDelayLineEdit_textEdited(const QString &startDelay)
{
    if (ui->startCuttingLineEdit->text().isEmpty())
    {
        ui->startCuttingLineEdit->setText("0");
    }
    if (ui->originalLengthCheckBox->isChecked())
    {
        ui->endDelayLineEdit->setText(startDelay);
    }
    if (!ui->inputFileLineEdit->text().isEmpty())
    {
        QString fileName = ui->inputFileLineEdit->text();
        GetInputFileInfo(ui->inputFileLineEdit->text().toUtf8().constData());
        CalculateTarget(fileName);
    }
}

void DelayCut::on_endDelayLineEdit_textEdited(const QString &endDelay)
{
    if (ui->startCuttingLineEdit->text().isEmpty())
    {
        ui->startCuttingLineEdit->setText("0");
    }
    if (!ui->inputFileLineEdit->text().isEmpty())
    {
        QString fileName = ui->inputFileLineEdit->text();
        GetInputFileInfo(ui->inputFileLineEdit->text().toUtf8().constData());
        CalculateTarget(fileName);
    }
}

void DelayCut::on_cutFileCheckBox_toggled(bool checked)
{
    if (checked && !ui->inputFileLineEdit->text().isEmpty())
    {
        QString fileName = ui->inputFileLineEdit->text();
        GetInputFileInfo(ui->inputFileLineEdit->text().toUtf8().constData());
        CalculateTarget(fileName);
    }
}

void DelayCut::on_quitButton_clicked()
{
    this->close();
}

void DelayCut::on_processButton_clicked()
{
    qreal startCut, endCut, startDelay, endDelay;
    QString fileName;

    if (ui->inputFileLineEdit->text().isEmpty())
    {
        QMessageBox::warning(this, "Error", "Fill input file path!");
        return;
    }
    if (ui->outputFileLineEdit->text().isEmpty())
    {
        QMessageBox::warning(this, "Error", "Fill output file path!");
        return;
    }

    if (ui->cutFileCheckBox->isChecked())
    {
        startCut = ui->startCuttingLineEdit->text().toInt() / 1000.0;
        endCut = ui->endCuttingLineEdit->text().toInt() / 1000.0;
    }
    else
    {
        endCut = startCut = 0.0;
    }

    startDelay = ui->startDelayLineEdit->text().toInt();
    endDelay = ui->endDelayLineEdit->text().toInt();

    ui->processButton->setEnabled(false);
    ui->quitButton->setEnabled(false);
    ui->abortButton->setEnabled(true);

    fileName = ui->inputFileLineEdit->text();
    logFileName = fileName.mid(0, fileName.lastIndexOf(".")) + "_log.txt";
    logInputInfo(logFileName, QFileInfo(ui->inputFileLineEdit->text()).suffix());
    logTargetInfo(logFileName, QFileInfo(ui->inputFileLineEdit->text()).suffix());

    bool ret = execute();

    if (abort)
    {
        QMessageBox::information(this, "Info", "Aborted!");
    }
    else if (ret)
    {
        QMessageBox::information(this, "Info", "Finished OK!");
    }
    else
    {
        QMessageBox::information(this, "Info", "Finished with error!");
    }

    ui->progressLabel->clear();
    ui->progressBar->setValue(0);

    ui->processButton->setEnabled(true);
    ui->quitButton->setEnabled(true);
    ui->abortButton->setEnabled(false);
}

void DelayCut::onUpdateProgress(qint32 value)
{
    if (value < 0)
    {
        value = 0;
    }
    if (value > 100)
    {
        value = 100;
    }
    ui->progressBar->setValue(value);
    ui->progressLabel->setText(QString("Processing... %1 %").arg(value));
}

qint32 DelayCut::logInputInfo(QString fileName, QString extension)
{
    logFile = fopen(fileName.toUtf8().constData(), "w");
    if (!logFile)
    {
        return -1;
    }
    else
    {
        if (extension!="wav")
        {
            fprintf(logFile, "[Input info]\n");
            fprintf(logFile, QString("Bitrate=%1\n").arg(fileInfo->iBitrate).toUtf8().constData());
            fprintf(logFile, QString("Actual rate=%1\n").arg(fileInfo->dactrate).toUtf8().constData());
            fprintf(logFile, QString("Sampling Frec=%1\n").arg(fileInfo->fsample).toUtf8().constData());
            fprintf(logFile, QString("TotalFrames=%1\n").arg(fileInfo->i64TotalFrames).toUtf8().constData());
            fprintf(logFile, QString("Bytesperframe=%1\n").arg(fileInfo->dBytesperframe, 9, 'f', 4).toUtf8().constData());
            fprintf(logFile, QString("Filesize=%1\n").arg(fileInfo->i64Filesize).toUtf8().constData());
            fprintf(logFile, QString("FrameDuration=%1\n").arg(fileInfo->dFrameduration, 8, 'f', 4).toUtf8().constData());
            fprintf(logFile, QString("Framespersecond=%1\n").arg(fileInfo->dFramesPerSecond, 8, 'f', 4).toUtf8().constData());
            fprintf(logFile, QString("Duration=%1\n").arg(fileInfo->csOriginalDuration).toUtf8().constData());
            fprintf(logFile, QString("Channels mode=%1\n").arg(fileInfo->csMode).toUtf8().constData());
            fprintf(logFile, QString("LFE=%1\n").arg(fileInfo->csLFE).toUtf8().constData());
        }
        else
        {
            fprintf(logFile, "[Input info]\n");
            fprintf(logFile, QString("Bitrate=%1\n").arg(fileInfo->iBitrate).toUtf8().constData());
            fprintf(logFile, QString("Actual rate=%1\n").arg(fileInfo->dactrate).toUtf8().constData());
            fprintf(logFile, QString("Byte rate=%1\n").arg(fileInfo->iByterate).toUtf8().constData());
            fprintf(logFile, QString("Sampling Frec=%1\n").arg(fileInfo->fsample).toUtf8().constData());
            fprintf(logFile, QString("Bits of Prec=%1\n").arg(fileInfo->iBits).toUtf8().constData());
            fprintf(logFile, QString("TotalSamples=%1\n").arg(fileInfo->i64TotalFrames).toUtf8().constData());
            fprintf(logFile, QString("Bytespersample=%1\n").arg(fileInfo->dBytesperframe, 9, 'f', 4).toUtf8().constData());
            fprintf(logFile, QString("Filesize=%1\n").arg(fileInfo->i64Filesize).toUtf8().constData());
            fprintf(logFile, QString("Duration=%1\n").arg(fileInfo->csOriginalDuration).toUtf8().constData());
            fprintf(logFile, QString("Channels mode=%1\n").arg(fileInfo->csMode).toUtf8().constData());
        }
        fclose(logFile);
        return 0;
    }
}

qint32 DelayCut::logTargetInfo(QString fileName, QString extension)
{
    logFile = fopen(fileName.toUtf8().constData(), "a");
    if (!logFile)
    {
        return -1;
    }
    else
    {
        if (extension!="wav")
        {
            fprintf(logFile, "[Target info]\n");
            fprintf(logFile, QString("StartFrame=%1\n").arg(fileInfo->i64StartFrame).toUtf8().constData());
            fprintf(logFile, QString("EndFrame=%1\n").arg(fileInfo->i64EndFrame).toUtf8().constData());
            fprintf(logFile, QString("NotFixedDelay=%1\n").arg(fileInfo->dNotFixedDelay, 8, 'f', 4).toUtf8().constData());
            fprintf(logFile, QString("Duration=%1\n").arg(fileInfo->csTimeLengthEst).toUtf8().constData());
        }
        else
        {
            fprintf(logFile, "[Target info]\n");
            fprintf(logFile, QString("StartSample=%1\n").arg(fileInfo->i64StartFrame).toUtf8().constData());
            fprintf(logFile, QString("EndSample=%1\n").arg(fileInfo->i64EndFrame).toUtf8().constData());
            fprintf(logFile, QString("NotFixedDelay=%1\n").arg(fileInfo->dNotFixedDelay, 8, 'f', 4).toUtf8().constData());
            fprintf(logFile, QString("Duration=%1\n").arg(fileInfo->csTimeLengthEst).toUtf8().constData());
        }
        fclose(logFile);
        return 0;
    }
}
